@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.http import HttpResponseRedirect
+from django.http import HttpResponsePermanentRedirect
 
 
 class SSLifyMiddleware(object):
@@ -13,4 +13,4 @@ class SSLifyMiddleware(object):
         if not any((settings.DEBUG, request.is_secure(), request.META.get('HTTP_X_FORWARDED_PROTO', '') == 'https')):
             url = request.build_absolute_uri(request.get_full_path())
             secure_url = url.replace('http://', 'https://')
-            return HttpResponseRedirect(secure_url)
+            return HttpResponsePermanentRedirect(secure_url)
